@@ -1,6 +1,7 @@
 package Astro::ADS;
-$Astro::ADS::VERSION = '1.90_70'; # TRIAL
-$Astro::ADS::VERSION = '1.9070';
+# ABSTRACT: Perl library to connect with the Harvard Astrophysical Data Service
+# https://ads.harvard.edu/
+$Astro::ADS::VERSION = '1.91.1';
 use Moo;
 
 use Carp;
@@ -49,7 +50,7 @@ sub _build_token {
         return $key;
     }
 
-    croak "You need to provide an API token.\nSee https://metacpan.org/pod/Astro::ADS#Getting-Started\n";
+    croak 'You need to provide an API token';
 }
 
 sub get_response {
@@ -94,6 +95,8 @@ sub post_response {
 
 1; # Perl is my Igor
 
+__END__
+
 =pod
 
 =encoding UTF-8
@@ -104,7 +107,7 @@ Astro::ADS - Perl library to connect with the Harvard Astrophysical Data Service
 
 =head1 VERSION
 
-version 1.90
+version 1.91.1
 
 =head1 SYNOPSIS
 
@@ -150,6 +153,10 @@ bottom of L<About ADS|https://ui.adsabs.harvard.edu/about/>.
 To acknowlegde use of this module, it will be sufficient to mention
 I<Perl's Astro::ADS is available at https://metacpan.org/pod/Astro::ADS>
 
+=head1 AUTHOR
+
+Boyd Duffee <duffee@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2025 by Boyd Duffee.
