@@ -1,6 +1,6 @@
 package Astro::ADS::Paper;
-$Astro::ADS::Paper::VERSION = '1.90_70'; # TRIAL
-$Astro::ADS::Paper::VERSION = '1.9070';
+# ABSTRACT: A class for holding the document attributes for the results of a Search
+$Astro::ADS::Paper::VERSION = '1.91.1';
 use Moo;
 
 use Carp;
@@ -73,6 +73,8 @@ sub summary {
 
 1;
 
+__END__
+
 =pod
 
 =encoding UTF-8
@@ -83,7 +85,7 @@ Astro::ADS::Paper - A class for holding the document attributes for the results
 
 =head1 VERSION
 
-version 1.90
+version 1.91.1
 
 =head1 SYNOPSIS
 
@@ -136,6 +138,10 @@ all of which grepped $self->links for either REFERENCES, CITATIONS, AR or TOC
 
 These are returned in the links_data field, but we should be using the Links service to get this data
 
+=head1 AUTHOR
+
+Boyd Duffee <duffee@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2025 by Boyd Duffee.
