@@ -1,7 +1,8 @@
 package Astro::ADS::Result;
-$Astro::ADS::Result::VERSION = '1.90_70'; # TRIAL
-$Astro::ADS::Result::VERSION = '1.9070';
+# ABSTRACT: A class for the results of a Search
+$Astro::ADS::Result::VERSION = '1.91.1';
 use Moo;
+#extends 'Astro::ADS';
 
 use Carp;
 use Data::Dumper::Concise;
@@ -31,7 +32,7 @@ has [qw/start rows/] => (
 );
 has error => (
     is       => 'rw',
-    isa      => HashRef[]
+    isa      => Str,
 );
 has docs => (
     is      => 'rw',
@@ -45,7 +46,7 @@ has docs => (
 before [qw/numFound numFoundExact start rows docs/] => sub {
    my ($self) = @_;
    if ($self->error ) {
-       carp 'Empty Result object: ', $self->error->{message};
+       carp 'Empty Result object: ', $self->error;
    }
 };
 
@@ -99,6 +100,8 @@ sub get_papers {
 
 1;
 
+__END__
+
 =pod
 
 =encoding UTF-8
@@ -109,7 +112,7 @@ Astro::ADS::Result - A class for the results of a Search
 
 =head1 VERSION
 
-version 1.90
+version 1.91.1
 
 =head1 SYNOPSIS
 
@@ -166,6 +169,10 @@ If given an argument, it takes that as the number of rows to fetch.
 
 =back
 
+=head1 AUTHOR
+
+Boyd Duffee <duffee@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2025 by Boyd Duffee.
