@@ -1,6 +1,7 @@
 package Astro::ADS::Role::ResultMapper;
-$Astro::ADS::Role::ResultMapper::VERSION = '1.90_70'; # TRIAL
-$Astro::ADS::Role::ResultMapper::VERSION = '1.9070';
+# ABSTRACT: Maps the JSON structure returned from an ADS search query
+# to a Astro::ADS::Result object
+$Astro::ADS::Role::ResultMapper::VERSION = '1.91.1';
 use Moo::Role;
 use strictures 2;
 
@@ -30,8 +31,11 @@ sub parse_response {
     return Astro::ADS::Result->new( $result_params );
 }
 
+
 1;
 
+__END__
+
 =pod
 
 =encoding UTF-8
@@ -39,11 +43,15 @@ sub parse_response {
 =head1 NAME
 
 Astro::ADS::Role::ResultMapper - Maps the JSON structure returned from an ADS search query
-to an Astro::ADS::Result object
 
 =head1 VERSION
 
-version 1.90
+version 1.91.1
+
+=head1 DESCRIPTION
+
+Takes the Mojo Response JSON and maps it to the Result object parameters,
+returning a Result object with Papers in the B<docs> attribute.
 
 =head1 SYNOPSIS 
 
@@ -54,10 +62,9 @@ version 1.90
     ...
     return $self->parse_response( $json );
 
-=head1 DESCRIPTION
+=head1 AUTHOR
 
-Takes the Mojo Response JSON and maps it to the Result object parameters,
-returning a Result object with Papers in the B<docs> attribute.
+Boyd Duffee <duffee@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
