@@ -1,6 +1,6 @@
 package Astro::ADS::Search;
-$Astro::ADS::Search::VERSION = '1.90_70'; # TRIAL
-$Astro::ADS::Search::VERSION = '1.9070';
+# ABSTRACT: Queries the ADS Search endpoint and collects the results
+$Astro::ADS::Search::VERSION = '1.91.1';
 use Moo;
 extends 'Astro::ADS';
 with 'Astro::ADS::Role::ResultMapper';
@@ -65,12 +65,7 @@ sub query {
     my $response = $self->get_response( $url );
     if ( $response->is_error ) {
         carp $response->message;
-        my $error_obj = {
-            message => $response->message,
-            query   => $search_terms,
-            url     => $url,
-        };
-        return Astro::ADS::Result->new( {error => $error_obj} );
+        return Astro::ADS::Result->new( {error => $response->message} );
     }
 
     my $json = $response->json;
@@ -163,6 +158,8 @@ sub add_objects {
 
 1;
 
+__END__
+
 =pod
 
 =encoding UTF-8
@@ -173,7 +170,7 @@ Astro::ADS::Search - Queries the ADS Search endpoint and collects the results
 
 =head1 VERSION
 
-version 1.90
+version 1.91.1
 
 =head1 SYNOPSIS
 
@@ -255,6 +252,10 @@ available with the author and title fields
 
 =back
 
+=head1 AUTHOR
+
+Boyd Duffee <duffee@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2025 by Boyd Duffee.
